==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SlackConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfig,io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfigBuilder>{
  public SlackConfigBuilder() {
    this(false);
  }
  public SlackConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new SlackConfig(), validationEnabled);
  }
  public SlackConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public SlackConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SlackConfig(), validationEnabled);
  }
  public SlackConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfig instance) {
    this(fluent, instance, false);
  }
  public SlackConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withActions(instance.getActions()); 
    fluent.withApiURL(instance.getApiURL()); 
    fluent.withCallbackId(instance.getCallbackId()); 
    fluent.withChannel(instance.getChannel()); 
    fluent.withColor(instance.getColor()); 
    fluent.withFallback(instance.getFallback()); 
    fluent.withFields(instance.getFields()); 
    fluent.withFooter(instance.getFooter()); 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withIconEmoji(instance.getIconEmoji()); 
    fluent.withIconURL(instance.getIconURL()); 
    fluent.withImageURL(instance.getImageURL()); 
    fluent.withLinkNames(instance.getLinkNames()); 
    fluent.withMrkdwnIn(instance.getMrkdwnIn()); 
    fluent.withPretext(instance.getPretext()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withShortFields(instance.getShortFields()); 
    fluent.withText(instance.getText()); 
    fluent.withThumbURL(instance.getThumbURL()); 
    fluent.withTitle(instance.getTitle()); 
    fluent.withTitleLink(instance.getTitleLink()); 
    fluent.withUsername(instance.getUsername()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SlackConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfig instance) {
    this(instance,false);
  }
  public SlackConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withActions(instance.getActions()); 
    this.withApiURL(instance.getApiURL()); 
    this.withCallbackId(instance.getCallbackId()); 
    this.withChannel(instance.getChannel()); 
    this.withColor(instance.getColor()); 
    this.withFallback(instance.getFallback()); 
    this.withFields(instance.getFields()); 
    this.withFooter(instance.getFooter()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withIconEmoji(instance.getIconEmoji()); 
    this.withIconURL(instance.getIconURL()); 
    this.withImageURL(instance.getImageURL()); 
    this.withLinkNames(instance.getLinkNames()); 
    this.withMrkdwnIn(instance.getMrkdwnIn()); 
    this.withPretext(instance.getPretext()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withShortFields(instance.getShortFields()); 
    this.withText(instance.getText()); 
    this.withThumbURL(instance.getThumbURL()); 
    this.withTitle(instance.getTitle()); 
    this.withTitleLink(instance.getTitleLink()); 
    this.withUsername(instance.getUsername()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfig build() {
    SlackConfig buildable = new SlackConfig(fluent.getActions(),fluent.getApiURL(),fluent.getCallbackId(),fluent.getChannel(),fluent.getColor(),fluent.getFallback(),fluent.getFields(),fluent.getFooter(),fluent.getHttpConfig(),fluent.getIconEmoji(),fluent.getIconURL(),fluent.getImageURL(),fluent.getLinkNames(),fluent.getMrkdwnIn(),fluent.getPretext(),fluent.getSendResolved(),fluent.getShortFields(),fluent.getText(),fluent.getThumbURL(),fluent.getTitle(),fluent.getTitleLink(),fluent.getUsername());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SlackConfigBuilder that = (SlackConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.0.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SlackConfigBuilder extends SlackConfigFluentImpl<SlackConfigBuilder> implements VisitableBuilder<SlackConfig,SlackConfigBuilder>{
  public SlackConfigBuilder() {
    this(false);
  }
  public SlackConfigBuilder(Boolean validationEnabled) {
    this(new SlackConfig(), validationEnabled);
  }
  public SlackConfigBuilder(SlackConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public SlackConfigBuilder(SlackConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SlackConfig(), validationEnabled);
  }
  public SlackConfigBuilder(SlackConfigFluent<?> fluent,SlackConfig instance) {
    this(fluent, instance, false);
  }
  public SlackConfigBuilder(SlackConfigFluent<?> fluent,SlackConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withActions(instance.getActions()); 
    fluent.withApiURL(instance.getApiURL()); 
    fluent.withCallbackId(instance.getCallbackId()); 
    fluent.withChannel(instance.getChannel()); 
    fluent.withColor(instance.getColor()); 
    fluent.withFallback(instance.getFallback()); 
    fluent.withFields(instance.getFields()); 
    fluent.withFooter(instance.getFooter()); 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withIconEmoji(instance.getIconEmoji()); 
    fluent.withIconURL(instance.getIconURL()); 
    fluent.withImageURL(instance.getImageURL()); 
    fluent.withLinkNames(instance.getLinkNames()); 
    fluent.withMrkdwnIn(instance.getMrkdwnIn()); 
    fluent.withPretext(instance.getPretext()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withShortFields(instance.getShortFields()); 
    fluent.withText(instance.getText()); 
    fluent.withThumbURL(instance.getThumbURL()); 
    fluent.withTitle(instance.getTitle()); 
    fluent.withTitleLink(instance.getTitleLink()); 
    fluent.withUsername(instance.getUsername()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SlackConfigBuilder(SlackConfig instance) {
    this(instance,false);
  }
  public SlackConfigBuilder(SlackConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withActions(instance.getActions()); 
    this.withApiURL(instance.getApiURL()); 
    this.withCallbackId(instance.getCallbackId()); 
    this.withChannel(instance.getChannel()); 
    this.withColor(instance.getColor()); 
    this.withFallback(instance.getFallback()); 
    this.withFields(instance.getFields()); 
    this.withFooter(instance.getFooter()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withIconEmoji(instance.getIconEmoji()); 
    this.withIconURL(instance.getIconURL()); 
    this.withImageURL(instance.getImageURL()); 
    this.withLinkNames(instance.getLinkNames()); 
    this.withMrkdwnIn(instance.getMrkdwnIn()); 
    this.withPretext(instance.getPretext()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withShortFields(instance.getShortFields()); 
    this.withText(instance.getText()); 
    this.withThumbURL(instance.getThumbURL()); 
    this.withTitle(instance.getTitle()); 
    this.withTitleLink(instance.getTitleLink()); 
    this.withUsername(instance.getUsername()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SlackConfigFluent<?> fluent;
  Boolean validationEnabled;
  public SlackConfig build() {
    SlackConfig buildable = new SlackConfig(fluent.getActions(),fluent.getApiURL(),fluent.getCallbackId(),fluent.getChannel(),fluent.getColor(),fluent.getFallback(),fluent.getFields(),fluent.getFooter(),fluent.getHttpConfig(),fluent.getIconEmoji(),fluent.getIconURL(),fluent.getImageURL(),fluent.getLinkNames(),fluent.getMrkdwnIn(),fluent.getPretext(),fluent.getSendResolved(),fluent.getShortFields(),fluent.getText(),fluent.getThumbURL(),fluent.getTitle(),fluent.getTitleLink(),fluent.getUsername());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
